@@ -19,5 +19,8 @@
 /* Define if you have the compress2 function.  */
 #undef HAVE_COMPRESS2
 
+/* Define if you have a newer libbz2 implementation function.  */
+#undef HAVE_NEW_BZ2
+
 /* Define if you have the inet_aton function.  */
 #undef HAVE_INET_ATON
