@@ -1,8 +1,7 @@
-
 #include "dact.h"
 #include "config.h"
 
-#if defined(USE_MODULES) && defined(COMP_MZLIB_IS_MOD) && !defined(AS_MODULE) && defined(USE_ZLIB)
+#if defined(USE_MODULES) && !defined(AS_MODULE)
 #define comp_mzlib_algo DACT_FAILED_ALGO
 #else
 int comp_mzlib_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
