@@ -70,12 +70,13 @@ int comp_snibble_compress(unsigned char *prev_block, unsigned char *curr_block,
 	char *curr_cpy;
 	const static unsigned char hash_table[4]={0, 2, 6, 7};
 	const static unsigned char hash_len[8]=  {1, 0, 2, 0, 0, 0, 3, 3};
-	FOUR_BYTES freq[4]={0, 0, 0, 0};
+	uint32_t freq[4]={0, 0, 0, 0};
 	unsigned char lookup_table[4]={0, 0, 0, 0};
-	int outsize;
 	int i,x,m,g=0;
 
-	curr_cpy=malloc(blk_size);
+	if ((curr_cpy=malloc(blk_size))==NULL) {
+		return(-1);
+	}
 	memcpy(curr_cpy,curr_block,blk_size);
 
 	bit_buffer_purge();
@@ -87,16 +88,18 @@ int comp_snibble_compress(unsigned char *prev_block, unsigned char *curr_block,
 		freq[(int) ((curr_cpy[i]&0x03))]++;
 	}
 
-	int_sort(freq,4);
+	int_sort(freq,4,1);
 
-	for (i=0;i<4;i++) lookup_table[(freq[i]>>16)]=hash_table[i];
+	for (i=0;i<4;i++) lookup_table[freq[i]]=hash_table[i];
 
-	bit_buffer_write(freq[0]>>16,2);
-	bit_buffer_write(freq[1]>>16,2);
-	bit_buffer_write(freq[2]>>16,2);
+	bit_buffer_write(freq[0],2);
+	bit_buffer_write(freq[1],2);
+	bit_buffer_write(freq[2],2);
 
+/*
 	outsize=((int) ((((((float) (freq[0]&0xffff))/2)+(freq[1]&0xffff)+(((float) (freq[2]&0xffff)+(freq[3]&0xffff))*1.5))/4.0)+0.99));
 
+*/
 	for (i=0;i<blk_size;i++) {
 		for (x=0;x<4;x++) {
 			m=((curr_cpy[i]&(3<<(x*2)))>>( x*2 ))  ;
