@@ -1,12 +1,10 @@
 #include "dact.h"
 #include "config.h"
 
-#if defined(USE_MODULES) && defined(COMP_ZLIB_IS_MOD) && !defined(AS_MODULE)
+#if defined(USE_MODULES) && !defined(AS_MODULE)
 #define comp_zlib_algo DACT_FAILED_ALGO
 #else
-#ifdef USE_ZLIB
 int comp_zlib_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
 int comp_zlib_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
 int comp_zlib_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
 #endif
-#endif
