@@ -21,26 +21,35 @@ extern int optind, opterr, optopt;
 uint32_t DACT_BLK_SIZE=4088;
 
 int print_help(int argc, char **argv) {
-	printf("DACT %i.%i.%i-%s by Netfuel Design. <dact@rkeene.org>\n", DACT_VER_MAJOR, \
-		DACT_VER_MINOR, DACT_VER_REVISION,
+	printf("DACT %i.%i.%i-%s by Netfuel Design. <dact@rkeene.org>\n",
+		DACT_VER_MAJOR, DACT_VER_MINOR, DACT_VER_REVISION,
 #ifdef DEBUG
 		"dev"
 #else
 		"rel"
 #endif
 		);
-	printf("usage: %s [-dsfcvlCh] [-b NN] [-e NN] [-m CONF] [file ...]\n",argv[0]);
+	printf("usage: %s [-dsfcvl%sh] [-b NN] [-e NN] [-I NN] [-m CONF] [file ...]\n",argv[0],
+#ifndef DACT_UNSAFE
+		"C"
+#else
+		""
+#endif
+		);
+
 	printf("  -d          Decompress instead of compressing.\n");
 	printf("  -s          Give statistics rather than compress or decompress.\n");
 	printf("  -f          Force unsafe things to happen.\n");
 	printf("  -c          (De)compress to stdout.\n");
 	printf("  -v          Increase verbosity.\n");
 	printf("  -l          List available algorithms.\n");
-/*	printf("  -C          Complain when compression errors occur.\n");
-*/
+#ifndef DACT_UNSAFE
+	printf("  -C          Complain when compression errors occur.\n");
+#endif
 	printf("  -h          Give this help.\n");
 	printf("  -b NN       Use a block size of NN bytes for compression.\n");
 	printf("  -e NN       Exclude algorithm NN from being used.\n");
+	printf("  -I NN       Use ONLY 2 algorithms, NN and 0.\n");
 	printf("  -m CONF     Load config file CONF.\n");
 	printf("  file...     File(s) to (de)compress.  (If none given, use standard input).\n");
 	return(0);
@@ -172,6 +181,11 @@ uint32_t dact_blk_compress(char *algo, char *ret, const char *srcbuf, const uint
 	int i, highest_algo=0;
 	char smallest_algo;
 	uint32_t smallest_size=-1, x;
+#ifndef DACT_UNSAFE
+	char *verif_bf=NULL;
+	uint32_t m;
+	if ((verif_bf=malloc(size))==NULL) { PERROR("malloc"); return(0); }
+#endif
 
 	if ((tmpbuf=malloc(size*2))==NULL) { PERROR("malloc"); return(0); }
 
@@ -182,11 +196,30 @@ uint32_t dact_blk_compress(char *algo, char *ret, const char *srcbuf, const uint
 	for (i=0;i<=highest_algo;i++) {
 		if (algorithms[i]!=NULL && algorithms[i]!=DACT_FAILED_ALGO) {
 			x=algorithms[i](DACT_MODE_COMPR, NULL, srcbuf, tmpbuf, size);
+#ifndef DACT_UNSAFE
+			if ((x<smallest_size || smallest_size==-1) && x!=-1) {
+				m=algorithms[i](DACT_MODE_DECMP, NULL, tmpbuf, verif_bf, x);
+				if (memcmp(verif_bf, srcbuf,m) || m!=size) {
+					x=-1;
+					if (options[DACT_OPT_COMPLN]) {
+						PRINT_LINE;
+						fprintf(stderr, "dact: Compression verification failed on block using algoritm %i (%s)\n",i,algorithm_names[i]);
+					}
+				}
+			}
+#endif
 			if ((x<smallest_size || smallest_size==-1) && x!=-1) {
 				smallest_size=x;
 				smallest_algo=i;
 				if (smallbuf!=NULL) free(smallbuf);
-				if ((smallbuf=malloc(smallest_size))==NULL) { PERROR("malloc"); free(tmpbuf); return(0); }
+				if ((smallbuf=malloc(smallest_size))==NULL) { 
+					PERROR("malloc");
+					free(tmpbuf);
+#ifndef DACT_UNSAFE
+					free(verif_bf);
+#endif
+					return(0);
+				}
 				memcpy(smallbuf, tmpbuf, smallest_size);
 			}
 
@@ -198,8 +231,16 @@ uint32_t dact_blk_compress(char *algo, char *ret, const char *srcbuf, const uint
 	}
 
 	free(tmpbuf);
+#ifndef DACT_UNSAFE
+	free(verif_bf);
+#endif
+	if (smallest_size==-1) {
+		return(0);
+	}
 	memcpy(algo, &smallest_algo, sizeof(char));
 	memcpy(ret, smallbuf, smallest_size);
+/* This was MISSING !  memory leak. */
+	free(smallbuf);
 	return(smallest_size);
 }
 
@@ -456,7 +497,7 @@ int main(int argc, char **argv) {
 	int filecnt=0;
 	int in_fd, out_fd;
 	int mode=DACT_MODE_COMPR;
-	uint32_t i;
+	uint32_t i,x;
 
 
 	dact_loadconfig(DACT_CONFIG_FILE, options);
@@ -482,7 +523,7 @@ int main(int argc, char **argv) {
 		}
 	}
  
-	while ((opt=getopt(argc,argv,"dfsvcCm:e:lb:h"))!=-1) {
+	while ((opt=getopt(argc,argv,"dfsvcCI:m:e:lb:h"))!=-1) {
 		switch (opt) {
 			case 'd':
 				mode=DACT_MODE_DECMP;
@@ -521,6 +562,12 @@ int main(int argc, char **argv) {
 				}
 				return(0);
 				break;
+			case 'I':
+				x=atoi(optarg);
+				for (i=1;i<255;i++) {
+					if (i!=x) algorithms[i]=NULL;
+				}
+				break;
 			case '?':
 			case 'h':
 				return(print_help(argc,argv));
