@@ -5,7 +5,7 @@
 
 #define DACT_VER_MAJOR 0
 #define DACT_VER_MINOR 6
-#define DACT_VER_REVISION 5
+#define DACT_VER_REVISION 7
 
 #define DACT_MODE_COMPR 1
 #define DACT_MODE_DECMP 2
@@ -60,9 +60,10 @@ extern uint32_t DACT_BLK_SIZE;
 
 #define SANITY(x, y...) if ((x(y))<0) { PERROR(#x); return(-1); }
 #ifdef DEBUG
-#define SHOWVAL(x...) fprintf(stderr, "%s=%li\n", #x, (long) (x))
-#define SPOTVAR_NUM(x) fprintf(stderr, "%s=%li\n", #x, (long) x)
-#define SPOTVAR_STR(x) fprintf(stderr, "%s=\"%s\"\n", #x, x)
+#define SHOWVAL(x...) PRINT_LINE; fprintf(stderr, "dact: %s=%li\n", #x, (long) (x))
+#define SPOTVAR_NUM(x) PRINT_LINE; fprintf(stderr, "dact: %s=%li\n", #x, (long) x)
+#define SPOTVAR_STR(x) PRINT_LINE; fprintf(stderr, "dact: %s=\"%s\"\n", #x, x)
+#define CHECKPOINT PRINTERR("Checkpoint reached.")
 #else
 #define SHOWVAL(x...) x
 #define SPOTVAR_NUM(x) /**/
